##  Tenant ID
If the user credentials you provided have access to multiple SAP Signavio workspaces, specify the tenant ID of the workspace you want to integrate with. If the credentials are associated with only one workspace, you can leave this field blank.
If the field is left empty, the integration will attempt to retrieve the tenant ID automatically from SAP Signavio using the provided credentials. If successful, the tenant ID will be filled in for you.
You can find the tenant ID in Workspace information under the Help section of SAP Signavio workspace.
